@@ -19,18 +19,22 @@
 #include "exerciseconvert.moc"
 
 /* these includes are needed for KDE support */
-#include <kapplication.h>
+#include <kglobal.h>
+#include <klineedit.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <knumvalidator.h>
 
 /* these includes are needed for Qt support */
+#include <QApplication>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlineedit.h>
 #include <qpushbutton.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+
+//Added by qt3to4:
+#include <QGridLayout>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 /* standard C++ library includes */
 #include <stdlib.h>
@@ -41,15 +45,15 @@
 /* ----- public member functions ----- */
 
 /* constructor */
-ExerciseConvert::ExerciseConvert(QWidget * parent, const char * name):
-		ExerciseBase(parent, name)
+ExerciseConvert::ExerciseConvert(QWidget * parent):
+		ExerciseBase(parent)
 {
 #ifdef DEBUG
-	kdDebug() << "constructor ExerciseConvert()" << endl;
+	kDebug() << "constructor ExerciseConvert()";
 #endif
 
 	/* create a new task */
-	QApplication::setOverrideCursor(waitCursor); /* show the sand clock */
+	QApplication::setOverrideCursor(Qt::WaitCursor); /* show the sand clock */
 	createTask();
 	QApplication::restoreOverrideCursor(); /* show the normal cursor */
 
@@ -57,106 +61,98 @@ ExerciseConvert::ExerciseConvert(QWidget * parent, const char * name):
 	// result
 	m_currentState = _CHECK_TASK;
 
-	baseWidget = new QWidget(this, "baseWidget");
-	baseGrid = new QGridLayout(this, 1, 1, 0, -1, "baseGrid"); 
+	baseWidget = new QWidget(this);
+	baseWidget->setObjectName("baseWidget");
+	baseGrid = new QGridLayout( this );
+        baseGrid->setObjectName( "baseGrid" );
 	baseGrid->addWidget(baseWidget, 0, 0);
 
 	// this is a VBox
-	realLayout = new QVBoxLayout(baseWidget, 5, 5, "realLayout");
+	realLayout = new QVBoxLayout(baseWidget);
+	realLayout->setMargin(5);
+	realLayout->setSpacing(5);
+	realLayout->setObjectName("realLayout");
 
 	// add a spacer at the top of the VBox
 	QSpacerItem * v_spacer = new QSpacerItem(1, 1);
 	realLayout->addItem(v_spacer);
 
 	// now a line holding the task, input fields and result
-	QHBoxLayout * taskLineHBoxLayout = new QHBoxLayout(5, "taskLineHBoxLayout");
+	QHBoxLayout * taskLineHBoxLayout = new QHBoxLayout();
+	taskLineHBoxLayout->setObjectName("taskLineHBoxLayout");
+	taskLineHBoxLayout->setSpacing(5);
 	realLayout->addLayout(taskLineHBoxLayout);
 
 	// first left is the rational widget
-	m_rationalWidget = new RationalWidget(baseWidget, "m_rationalWidget", m_number, m_periodStart, m_periodLength);
-// 	taskLineHBoxLayout->addWidget(m_rationalWidget);
+	m_rationalWidget = new RationalWidget(baseWidget, m_number, m_periodStart, m_periodLength);
+	m_rationalWidget->setObjectName("m_rationalWidget");
+	taskLineHBoxLayout->addWidget(m_rationalWidget);
 
 	// now we have the input fields aligned in a VBox
-	QVBoxLayout * inputLayout = new QVBoxLayout(5, "inputLayout");
-//	taskLineHBoxLayout->addLayout(inputLayout);
+	QVBoxLayout * inputLayout = new QVBoxLayout();
+	inputLayout->setObjectName("inputLayout");
+	inputLayout->setSpacing(5);
+	taskLineHBoxLayout->addLayout(inputLayout);
 
 	// to validate, that the input is an int
 	KIntValidator *valnum = new KIntValidator( this );
 
 	/* add input box so the user can enter numerator */
-	numer_edit = new QLineEdit(baseWidget, "numer_edit");
+	numer_edit = new KLineEdit(baseWidget);
+	numer_edit->setObjectName("numer_edit");
 	numer_edit->setValidator( valnum ); // use the int validator
-	QToolTip::add(numer_edit, i18n("Enter the numerator of your result"));
+	numer_edit->setToolTip(i18n("Enter the numerator of your result"));
 	inputLayout->addWidget(numer_edit);
 
 	/* add a line between the edit boxes */
-	edit_line = new QFrame(baseWidget, "edit_line");
+	edit_line = new QFrame(baseWidget);
 	edit_line->setGeometry(QRect(100, 100, 20, 20));
 	edit_line->setFrameStyle(QFrame::HLine | QFrame::Sunken);
 	inputLayout->addWidget(edit_line);
 
 	/* add input box so the user can enter denominator */
-	deno_edit = new QLineEdit(baseWidget, "deno_edit");
+	deno_edit = new KLineEdit(baseWidget);
+	deno_edit->setObjectName("deno_edit");
 	deno_edit->setValidator( valnum ); // use the int validator
-	QToolTip::add(deno_edit, i18n("Enter the denominator of your result"));
+	deno_edit->setToolTip(i18n("Enter the denominator of your result"));
 	inputLayout->addWidget(deno_edit);
 
 	// next is the result widget
-	m_resultWidget = new ResultWidget(baseWidget, "m_resultWidget", m_result);
-// 	taskLineHBoxLayout->addWidget(m_resultWidget);
+	m_resultWidget = new ResultWidget(baseWidget, m_result);
+	m_resultWidget->setObjectName("m_resultWidget");
+	taskLineHBoxLayout->addWidget(m_resultWidget);
 	m_resultWidget->hide();
 
 	// at the right end we have a label just showing CORRECT or WRONG
-	result_label = new QLabel(baseWidget, "result_lable");
-	result_label->setText(i18n("WRONG"));
-// 	taskLineHBoxLayout->addWidget(result_label);
+	result_label = new QLabel(baseWidget);
+	result_label->setObjectName("result_lable");
+	//result_label->setText(i18n("WRONG")); // no need to set this, since it's hidden anyway (jpw)
+	taskLineHBoxLayout->addWidget(result_label);
 	result_label->hide();
 
 	// add another spacer in the middle of the VBox
 	v_spacer = new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum);
-// 	taskLineHBoxLayout->addItem(v_spacer);
+	taskLineHBoxLayout->addItem(v_spacer);
 
 	// --- that is the end of the horizontal line ---
 
-	// in RTL desktops, we still need to allign the
-	// execise to the left. On Qt4, you can set the direction
-	// of the layout to LTR (instead of inherit), but on Qt3
-	// the only way of fixing it is inserting the widgets in reversed
-	// order to the layout.
-	//
-	// if you need help with this feel free to contact me - Diego <elcuco@kde.org> )
-	// This should fix parts of bug #116831
-	if (QApplication::reverseLayout())
-	{
-		taskLineHBoxLayout->addItem(v_spacer);
-		taskLineHBoxLayout->addWidget(result_label);
-		taskLineHBoxLayout->addWidget(m_resultWidget);
-		taskLineHBoxLayout->addLayout(inputLayout);
-		taskLineHBoxLayout->addWidget(m_rationalWidget);
-	}
-	else
-	{
-		taskLineHBoxLayout->addWidget(m_rationalWidget);
-		taskLineHBoxLayout->addLayout(inputLayout);
-		taskLineHBoxLayout->addWidget(m_resultWidget);
-		taskLineHBoxLayout->addWidget(result_label);
-		taskLineHBoxLayout->addItem(v_spacer);
-	}
-	
 	// add another spacer in the middle of the VBox
 	v_spacer = new QSpacerItem(1, 1);
 	realLayout->addItem(v_spacer);
 
 	// the lower part of the VBox holds just a right aligned button
-	QHBoxLayout * lowerHBox = new QHBoxLayout(1, "lowerHBox");
+	QHBoxLayout * lowerHBox = new QHBoxLayout();
+	lowerHBox->setObjectName("lowerHBox");
+	lowerHBox->setSpacing(1);
 	realLayout->addLayout(lowerHBox);
 	lowerHBox->addStretch(100);
 
 	// the right aligned button
-	m_checkButton = new QPushButton( baseWidget, "m_checkButton" );
+	m_checkButton = new QPushButton( baseWidget );
+	m_checkButton->setObjectName( "m_checkButton" );
 	m_checkButton->setText(i18n("&Check Task"));
 	m_checkButton->setDefault(true); // is the default button of the dialog
-	QToolTip::add(m_checkButton, i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
+	m_checkButton->setToolTip(i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
 	lowerHBox->addWidget(m_checkButton, 1, Qt::AlignRight);
 	QObject::connect(m_checkButton, SIGNAL(clicked()), this, SLOT(slotCheckButtonClicked()));
 
@@ -167,15 +163,15 @@ ExerciseConvert::ExerciseConvert(QWidget * parent, const char * name):
 	baseWidget->show();
 
 	// add tooltip and qwhatsthis help to the widget
-	QToolTip::add(this, i18n("In this exercise you have to convert a number into a fraction."));
-	QWhatsThis::add(this, i18n("In this exercise you have to convert a given number into a fraction by entering numerator and denominator. Do not forget to reduce the result!"));
+	setToolTip(i18n("In this exercise you have to convert a number into a fraction."));
+	setWhatsThis( i18n("In this exercise you have to convert a given number into a fraction by entering numerator and denominator. Do not forget to reduce the result."));
 }
 
 /* destructor */
 ExerciseConvert::~ExerciseConvert()
 {
 #ifdef DEBUG
-	kdDebug() << "destructor ExerciseConvert()" << endl;
+	kDebug() << "destructor ExerciseConvert()";
 #endif
 
 	/* no need to delete any child widgets, Qt does it by itself */
@@ -187,7 +183,7 @@ ExerciseConvert::~ExerciseConvert()
 void ExerciseConvert::forceNewTask()
 {
 #ifdef DEBUG
-	kdDebug() << "forceNewTask ExerciseConvert()" << endl;
+	kDebug() << "forceNewTask ExerciseConvert()";
 #endif
 
 	if (m_currentState == _CHECK_TASK)
@@ -331,11 +327,10 @@ void ExerciseConvert::showResult()
 {
 	QString tmp_str; /* to build a string for a label */
 	QPalette pal;
-	QColorGroup cg;
 	ratio entered_result;
 
 	// change the tooltip of the check button
-	QToolTip::add(m_checkButton, i18n("Click on this button to get to the next task."));
+	m_checkButton->setToolTip(i18n("Click on this button to get to the next task."));
 
 	numer_edit->setEnabled(false);
 	deno_edit->setEnabled(false);
@@ -369,14 +364,10 @@ void ExerciseConvert::showResult()
 		signalExerciseSolvedCorrect();
 
 		/* yes, the user entered the correct result */
-		result_label->setText(i18n("CORRECT"));
+		result_label->setText(i18nc("@info:status the answer given was correct", "CORRECT"));
 		pal = result_label->palette(); /* set green font color */
-		cg = pal.active();
-		cg.setColor(QColorGroup::Foreground, QColor(6, 179, 0));
-		pal.setActive(cg);
-		cg = pal.inactive();
-		cg.setColor(QColorGroup::Foreground, QColor(6, 179, 0));
-		pal.setInactive(cg);
+        pal.setColor(QPalette::Active, QPalette::Foreground, QColor(6, 179, 0));
+        pal.setColor(QPalette::Inactive, QPalette::Foreground, QColor(6, 179, 0));
 		result_label->setPalette(pal);
 		result_label->show(); /* show the result at the end of the task */
 	} else {
@@ -384,14 +375,10 @@ void ExerciseConvert::showResult()
 		signalExerciseSolvedWrong();
 
 		/* no, the user entered the wrong result */
-		result_label->setText(i18n("WRONG"));
+		result_label->setText(i18nc("@info:status the answer given was incorrect", "WRONG"));
 		pal = result_label->palette(); /* set red font color */
-		cg = pal.active();
-		cg.setColor(QColorGroup::Foreground, QColor(red));
-		pal.setActive(cg);
-		cg = pal.inactive();
-		cg.setColor(QColorGroup::Foreground, QColor(red));
-		pal.setInactive(cg);
+        pal.setColor(QPalette::Active, QPalette::Foreground, QColor(Qt::red));
+        pal.setColor(QPalette::Inactive, QPalette::Foreground, QColor(Qt::red));
 		result_label->setPalette(pal);
 
 		result_label->show(); /* show the result at the end of the task */
@@ -420,7 +407,7 @@ void ExerciseConvert::showResult()
 void ExerciseConvert::nextTask()
 {
 	// change the tooltip of the check button
-	QToolTip::add(m_checkButton, i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
+	m_checkButton->setToolTip(i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
 
 	numer_edit->setEnabled(true);
 	deno_edit->setEnabled(true);
@@ -434,7 +421,7 @@ void ExerciseConvert::nextTask()
 	numer_edit->setFocus();
 
 	/* create a new task */
-	QApplication::setOverrideCursor(waitCursor); /* show the sand clock */
+	QApplication::setOverrideCursor(Qt::WaitCursor); /* show the sand clock */
 	createTask();
 	QApplication::restoreOverrideCursor(); /* show the normal cursor */
 
