@@ -20,8 +20,6 @@
 #ifndef BRUCH_H
 #define BRUCH_H
 
-#include <config.h>
-
 /* for the I18N_NOOP macro */
 #include <klocale.h>
 
@@ -31,9 +29,6 @@
 static const char description[] =
 	I18N_NOOP("KBruch");
 
-class MainQtWidget;
 class task;
-class ratio;
-class primzahl;
 
 #endif /* ifndef BRUCH_H */
