@@ -23,20 +23,22 @@
 
 /* these includes are needed for Qt support */
 #include <qpainter.h>
+//Added by qt3to4:
+#include <QPaintEvent>
 
-TaskWidget::TaskWidget(QWidget * parent = 0, const char * name = 0,
-													const task para_task = *new task()) :
-			FractionBaseWidget(parent, name), m_task(para_task)
+TaskWidget::TaskWidget(QWidget * parent = 0,
+													const task para_task = task()) :
+			FractionBaseWidget(parent), m_task(para_task)
 {
 #ifdef DEBUG
-	kdDebug() << "constructor TaskWidget" << endl;
+	kDebug() << "constructor TaskWidget";
 #endif
 }
 
 TaskWidget::~TaskWidget()
 {
 #ifdef DEBUG
-	kdDebug() << "destructor TaskWidget" << endl;
+	kDebug() << "destructor TaskWidget";
 #endif
 }
 
@@ -70,7 +72,7 @@ void TaskWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
 	paint.setPen(pen);
 
 	// get the font height; the font height doesn't change while painting
-	QFontMetrics fm(paint.fontMetrics());
+	QFontMetrics  fm(paint.fontMetrics());
 
 	// now we can correctly set the height of the widget
 	setMinimumHeight(2 * fm.lineSpacing() + 10);
@@ -104,7 +106,7 @@ void TaskWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
 				case DIV :
 					// there seems to be different division signs around the world
 					// so please translate it to the right one for your country
-					str_operation = i18n("division symbol", "/");
+					str_operation = i18nc("division symbol", "/");
 					break;
 			} /* switch (operation) */
 
