@@ -11,18 +11,20 @@
 #ifndef MAPCHOOSER_H
 #define MAPCHOOSER_H
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 
-#include <qdict.h>
+#include <qhash.h>
 
 #include "map.h"
 #include "mapparser.h"
 
-class mapChooser : public KDialogBase
+class QListWidget;
+class QLabel;
+class mapChooser : public KDialog
 {
 Q_OBJECT
 	public:
-		mapChooser(QWidget *parent);
+		explicit mapChooser(QWidget *parent);
 		~mapChooser();
 
 		KGmap *getMap();
@@ -31,10 +33,10 @@ Q_OBJECT
 		void putImage(const QString &mapName);
 
 	private:
-		QListBox *p_listBox;
-		QWidget *p_image;
+		QListWidget *p_listBox;
+		QLabel *p_image;
 		mapReader p_reader;
-		QDict<KGmap> p_maps;
+		QHash<QString, KGmap*> p_maps;
 };
 
 #endif
