@@ -18,7 +18,6 @@
 
 #include "drgeo-filter.h"
 
-#include "drgeo-filter-chooser.h"
 #include "filters-common.h"
 
 #include "../kig/kig_document.h"
@@ -53,7 +52,9 @@
 
 #include <qfile.h>
 #include <qnamespace.h>
+#include <QDomDocument>
 
+#include <kinputdialog.h>
 #include <klocale.h>
 
 #undef DRGEO_DEBUG
@@ -81,7 +82,7 @@ bool KigFilterDrgeo::supportMime( const QString& mime )
 KigDocument* KigFilterDrgeo::load( const QString& file )
 {
   QFile f( file );
-  if ( ! f.open( IO_ReadOnly ) )
+  if ( ! f.open( QIODevice::ReadOnly ) )
   {
     fileNotFound( file );
     return 0;
@@ -106,9 +107,9 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
   if ( figures.isEmpty() ) {
     if( nmacros > 0 )
       warning( i18n( "The Dr. Geo file \"%1\" is a macro file so it contains no "
-                     "figures." ).arg( file ) );
+                     "figures.", file ) );
     else
-      warning( i18n( "There are no figures in Dr. Geo file \"%1\"." ).arg( file ) );
+      warning( i18n( "There are no figures in Dr. Geo file \"%1\".", file ) );
     return false;
   }
 
@@ -117,20 +118,24 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
   if ( nfig == 0 )
     return 0;
 
-  int myfig = 0;
-  
+  QString myfig = figures.at( 0 );
+
   if ( nfig > 1 )
   {
     // Dr. Geo file has more than 1 figure, let the user choose one...
-    KigFilterDrgeoChooser* c = new KigFilterDrgeoChooser( figures );
-    myfig = c->exec();
-    delete c;
+    bool ok = true;
+    myfig = KInputDialog::getItem(
+                i18n( "Dr. Geo Filter" ),
+                i18n( "The current Dr. Geo file contains more than one figure.\n"
+                      "Please select which to import:" ),
+                figures, 0, false, &ok );
+    if ( !ok )
+      return 0;
   }
 
 #ifdef DRGEO_DEBUG
-  kdDebug() << "drgeo file " << file << endl;
+  kDebug() << "drgeo file " << file;
 #endif
-  int curfig = -1;
 
   for ( QDomNode n = main.firstChild(); ! n.isNull(); n = n.nextSibling() )
   {
@@ -138,11 +143,10 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
     if ( e.isNull() ) continue;
     else if ( e.tagName() == "drgeo" )
     {
-      curfig += 1;
-      if ( curfig == myfig )
+      if ( e.attribute("name") == myfig )
       {
 #ifdef DRGEO_DEBUG
-        kdDebug() << "- Figure: '" << e.attribute("name") << "'" << endl;
+        kDebug() << "- Figure: '" << e.attribute("name") << "'";
 #endif
         bool grid = !e.attribute( "grid" ).isEmpty() &&
                     ( e.attribute( "grid" ) != "False" );
@@ -154,7 +158,7 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
   return 0;
 }
 
-int convertDrgeoIndex( const std::vector<DrGeoHierarchyElement> es, const QString myid )
+static int convertDrgeoIndex( const std::vector<DrGeoHierarchyElement>& es, const QString& myid )
 {
   for ( uint i = 0; i < es.size(); ++i )
     if ( es[i].id == myid )
@@ -162,7 +166,7 @@ int convertDrgeoIndex( const std::vector<DrGeoHierarchyElement> es, const QStrin
   return -1;
 }
 
-const Coordinate convertDrgeoLineParam( const double param, const LineData& line )
+static const Coordinate convertDrgeoLineParam( const double param, const LineData& line )
 {
   const double n = ( param - 0.5 ) * M_PI;
   const Coordinate c = line.dir() / line.dir().length();
@@ -170,7 +174,7 @@ const Coordinate convertDrgeoLineParam( const double param, const LineData& line
   return p;
 }
 
-const Coordinate convertDrgeoHalflineParam( const double param, const LineData& line )
+static const Coordinate convertDrgeoHalflineParam( const double param, const LineData& line )
 {
   const double n = param * M_PI * 0.5;
   const Coordinate c = line.dir() / line.dir().length();
@@ -178,7 +182,7 @@ const Coordinate convertDrgeoHalflineParam( const double param, const LineData&
   return p;
 }
 
-KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, const bool grid )
+KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& file, const bool grid )
 {
   KigDocument* ret = new KigDocument();
 
@@ -195,7 +199,7 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
     {
       DrGeoHierarchyElement elem;
 #ifdef DRGEO_DEBUG
-      kdDebug() << "  * " << domelem.tagName() << "(" << domelem.attribute("type") << ")" << endl;
+      kDebug() << "  * " << domelem.tagName() << "(" << domelem.attribute("type") << ")";
 #endif
       for ( QDomNode c = domelem.firstChild(); ! c.isNull(); c = c.nextSibling() )
       {
@@ -212,15 +216,15 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
 
 #ifdef DRGEO_DEBUG
   QString x;
-  kdDebug() << "+++ elems" << endl;
+  kDebug() << "+++ elems";
   for ( uint i = 0; i < elems.size(); ++i )
   {
     x = "";
     for ( uint j = 0; j < elems[i].parents.size(); ++j )
     {
-      x += elems[i].parents[j] + "_";
+      x += elems[i].parents[j] + '_';
     }
-    kdDebug() << "  --> " << i << " - " << elems[i].id << " - " << x << endl;
+    kDebug() << "  --> " << i << " - " << elems[i].id << " - " << x;
   }
 #endif
 
@@ -238,7 +242,7 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
   for (QDomNode a = f; ! a.isNull(); a = a.nextSibling() )
   {
 #ifdef DRGEO_DEBUG
-    kdDebug() << "+++ id: " << curid << endl;
+    kDebug() << "+++ id: " << curid;
 #endif
     const DrGeoHierarchyElement& el = elems[curid];
     std::vector<ObjectCalcer*> parents;
@@ -255,12 +259,12 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
     if ( parents.size() > 0 )
       for ( uint j = 0; j < parents.size(); ++j )
       {
-        kdDebug() << "+++++++++ parent[" << j << "]: " << parents[j] << " - "
+        kDebug() << "+++++++++ parent[" << j << "]: " << parents[j] << " - "
                   << parents[j]->imp()->type()->internalName() << endl;
       }
     else
-      kdDebug() << "+++++++++ parents: NO" << endl;
-    kdDebug() << "+++++++++ " << domelem.tagName() << " - " << domelem.attribute("type") << endl;
+      kDebug() << "+++++++++ parents: NO";
+    kDebug() << "+++++++++ " << domelem.tagName() << " - " << domelem.attribute("type");
 #endif
 
     if ( domelem.isNull() ) continue;
@@ -333,7 +337,7 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         {
 //          oc = fact->constrainedPointCalcer( parents[0], value );
           notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                    "which Kig does not currently support.", domelem.tagName() , 
                                       domelem.attribute( "type" ) ) );
           return false;
         }
@@ -376,6 +380,8 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
           oc = new ObjectTypeCalcer( type, args );
         }
       }
+      else if ( domelem.attribute( "type" ) == "Coordinate" )
+        oc = new ObjectTypeCalcer( PointByCoordsType::instance(), parents );
       else if ( domelem.attribute( "type" ) == "Reflexion" )
         oc = new ObjectTypeCalcer( LineReflectionType::instance(), parents );
       else if ( domelem.attribute( "type" ) == "Symmetry" )
@@ -384,15 +390,17 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         oc = new ObjectTypeCalcer( TranslatedType::instance(), parents );
       else if ( domelem.attribute( "type" ) == "Rotation" )
         oc = new ObjectTypeCalcer( RotationType::instance(), parents );
+      else if ( domelem.attribute( "type" ) == "Scale" )
+        oc = new ObjectTypeCalcer( ScalingOverCenterType::instance(), parents );
       else
       {
         notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                  "which Kig does not currently support.", domelem.tagName() , 
                                     domelem.attribute( "type" ) ) );
         return false;
       }
 #ifdef DRGEO_DEBUG
-      kdDebug() << "+++++++++ oc:" << oc << endl;
+      kDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if( ( domelem.tagName() == "line" ) ||
@@ -419,7 +427,7 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         else
         {
           notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                    "which Kig does not currently support.", domelem.tagName() , 
                                     domelem.attribute( "type" ) ) );
           return false;
         }
@@ -432,28 +440,30 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         else
         {
           notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                    "which Kig does not currently support.", domelem.tagName() , 
                                     domelem.attribute( "type" ) ) );
           return false;
         }
         oc = new ObjectTypeCalcer( type, parents );
       }
-      else if( domelem.attribute( "type" ) == "segment" )
+      else if ( ( domelem.attribute( "type" ) == "segment" ) ||
+                ( domelem.attribute( "type" ) == "radius" ) )
       {
         if( domelem.tagName() == "circle" )
         {
           type = CircleBPRType::instance();
-          ObjectPropertyCalcer* o = fact->propertyObjectCalcer( parents[1], "length" );
-          o->calc( *ret );
-          ObjectCalcer* a = parents[0];
-          parents.clear();
-          parents.push_back( a );
-          parents.push_back( o );
+          if ( domelem.attribute( "type" ) == "segment" )
+          {
+            ObjectPropertyCalcer* o = fact->propertyObjectCalcer( parents[1], "length" );
+            o->calc( *ret );
+            parents.pop_back();
+            parents.push_back( o );
+          }
         }
         else
         {
           notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                    "which Kig does not currently support.", domelem.tagName() , 
                                     domelem.attribute( "type" ) ) );
           return false;
         }
@@ -469,7 +479,7 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         else
         {
           notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                    "which Kig does not currently support.", domelem.tagName() , 
                                     domelem.attribute( "type" ) ) );
           return false;
         }
@@ -487,15 +497,17 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         oc = new ObjectTypeCalcer( TranslatedType::instance(), parents );
       else if ( domelem.attribute( "type" ) == "Rotation" )
         oc = new ObjectTypeCalcer( RotationType::instance(), parents );
+      else if ( domelem.attribute( "type" ) == "Scale" )
+        oc = new ObjectTypeCalcer( ScalingOverCenterType::instance(), parents );
       else
       {
         notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                  "which Kig does not currently support.", domelem.tagName() , 
                                   domelem.attribute( "type" ) ) );
         return false;
       }
 #ifdef DRGEO_DEBUG
-      kdDebug() << "+++++++++ oc:" << oc << endl;
+      kDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if( ( domelem.tagName() == "numeric" ) ||
@@ -523,14 +535,13 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         KIG_FILTER_PARSE_ERROR;
       Coordinate m( x, y );
       // types of 'numeric'
-      // ugly hack to show value numerics...
       if ( domelem.attribute( "type" ) == "value" )
       {
         bool ok3;
         double dvalue = value.toDouble( &ok3 );
-        if ( ok3 )
-          value = QString( "%1" ).arg( dvalue, 0, 'g', 3 );
-        oc = fact->labelCalcer( value, m, false, std::vector<ObjectCalcer*>(), *ret );
+        if ( !ok3 )
+          KIG_FILTER_PARSE_ERROR;
+        oc = fact->numericValueCalcer( dvalue, m, *ret );
       }
       else if ( domelem.attribute( "type" ) == "pt_abscissa" )
       {
@@ -618,12 +629,12 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
       else
       {
         notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                  "which Kig does not currently support.", domelem.tagName() , 
                                   domelem.attribute( "type" ) ) );
         return false;
       }
 #ifdef DRGEO_DEBUG
-      kdDebug() << "+++++++++ oc:" << oc << endl;
+      kDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if ( domelem.tagName() == "angle" )
@@ -636,12 +647,12 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
       else
       {
         notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                  "which Kig does not currently support.", domelem.tagName() , 
                                   domelem.attribute( "type" ) ) );
         return false;
       }
 #ifdef DRGEO_DEBUG
-      kdDebug() << "+++++++++ oc:" << oc << endl;
+      kDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if ( domelem.tagName() == "script" )
@@ -677,7 +688,7 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
       else
       {
         notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                  "which Kig does not currently support.", domelem.tagName() , 
                                   domelem.attribute( "type" ) ) );
         return false;
       }
@@ -689,12 +700,12 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
       else
       {
         notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                  "which Kig does not currently support.", domelem.tagName() , 
                                   domelem.attribute( "type" ) ) );
         return false;
       }
 #ifdef DRGEO_DEBUG
-      kdDebug() << "+++++++++ oc:" << oc << endl;
+      kDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if ( ( domelem.tagName() == "boundingBox" ) ||
@@ -706,10 +717,10 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
     else
     {
 #ifdef DRGEO_DEBUG
-      kdDebug() << ">>>>>>>>> UNKNOWN OBJECT" << endl;
+      kDebug() << ">>>>>>>>> UNKNOWN OBJECT";
 #endif
       notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                "which Kig does not currently support.", domelem.tagName() , 
                                 domelem.attribute( "type" ) ) );
       return false;
     }
@@ -760,9 +771,13 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
     holders.push_back( o );
 // calc()
 #ifdef DRGEO_DEBUG
-    kdDebug() << ">>>>>>>>> calc" << endl;
+    kDebug() << ">>>>>>>>> calc";
 #endif
     holders[curid-1-nignored]->calc( *ret );
+#ifdef DRGEO_DEBUG
+    kDebug() << "+++++++++ oc: " << oc << " - "
+              << oc->imp()->type()->internalName() << endl;
+#endif
 
     if ( domelem.tagName() == "point" )
     {
