@@ -18,6 +18,8 @@
  USA
 **/
 
+#include <math.h>
+
 #include "common.h"
 
 #include "../kig/kig_view.h"
@@ -28,11 +30,8 @@
 #include <kdebug.h>
 #include <knumvalidator.h>
 #include <klocale.h>
-#if KDE_IS_VERSION( 3, 1, 90 )
+#include <kglobal.h>
 #include <kinputdialog.h>
-#else
-#include <klineeditdlg.h>
-#endif
 
 Coordinate calcPointOnPerpend( const LineData& l, const Coordinate& t )
 {
@@ -182,7 +181,7 @@ void calcRayBorderPoints( const double xa, const double ya, double& xb,
     yb = r.bottom();
     return;
   };
-  kdError() << k_funcinfo << "damn" << endl;
+  kError() << "damn" << endl;
 }
 
 bool isOnLine( const Coordinate& o, const Coordinate& a,
@@ -193,7 +192,7 @@ bool isOnLine( const Coordinate& o, const Coordinate& a,
   double x2 = b.x;
   double y2 = b.y;
 
-  // check your math theory ( homogeneous cordinates ) for this
+  // check your math theory ( homogeneous coordinates ) for this
   double tmp = fabs( o.x * (y1-y2) + o.y*(x2-x1) + (x1*y2-y1*x2) );
   return tmp < ( fault * (b-a).length());
   // if o is on the line ( if the determinant of the matrix
@@ -349,21 +348,11 @@ Coordinate calcCircleRadicalStartPoint( const Coordinate& ca, const Coordinate&
 double getDoubleFromUser( const QString& caption, const QString& label, double value,
                           QWidget* parent, bool* ok, double min, double max, int decimals )
 {
-#ifdef KIG_USE_KDOUBLEVALIDATOR
-  KDoubleValidator vtor( min, max, decimals, 0, 0 );
-#else
-  KFloatValidator vtor( min, max, (QWidget*) 0, 0 );
-#endif
-#if KDE_IS_VERSION( 3, 1, 90 )
+  KDoubleValidator vtor( min, max, decimals,0 );
+
   QString input = KInputDialog::getText(
     caption, label, KGlobal::locale()->formatNumber( value, decimals ),
-    ok, parent, "getDoubleFromUserDialog", &vtor );
-#else
-  QString input =
-    KLineEditDlg::getText( caption, label,
-                           KGlobal::locale()->formatNumber( value, decimals ),
-                           ok, parent, &vtor );
-#endif
+    ok, parent, &vtor );
 
   bool myok = true;
   double ret = KGlobal::locale()->readNumber( input, &myok );
@@ -396,7 +385,7 @@ const Coordinate calcCenter(
     // this means that the lines ac and ab have the same direction,
     // which means they're the same line..
     // FIXME: i would normally throw an error here, but KDE doesn't
-    // use exceptions, so i'm returning a bogus point :(
+    // use exceptions, so I'm returning a bogus point :(
     return a.invalidCoord();
     /* return (a+c)/2; */
   };
