@@ -28,15 +28,13 @@
 
 #include <qpainter.h>
 #include <qcolor.h>
+#include <qfont.h>
 
 #include <vector>
 
 class KigWidget;
 class QPaintDevice;
 class CoordinateSystem;
-class ObjectHierarchy;
-class ConicPolarData;
-class CubicCartesianData;
 class LineData;
 class CurveImp;
 class KigDocument;
@@ -51,7 +49,7 @@ class ObjectHolder;
  * It calls KigWidget::appendOverlay() for all of the places it draws in...
  */
 class KigPainter
-  : public Qt
+//  : public Qt
 {
 protected:
   // don't blaim me for this mutable hack.  It's TT that hasn't got
@@ -59,10 +57,10 @@ protected:
   mutable QPainter mP;
 
   QColor color;
-  PenStyle style;
+  Qt::PenStyle style;
   int pointstyle;
   int width;
-  BrushStyle brushStyle;
+  Qt::BrushStyle brushStyle;
   QColor brushColor;
 
   const KigDocument& mdoc;
@@ -70,6 +68,7 @@ protected:
 
   bool mNeedOverlay;
   int overlayenlarge;
+  bool mSelected;
 public:
   /**
    * construct a new KigPainter:
@@ -87,26 +86,30 @@ public:
    */
   Rect window();
 
-  QPoint toScreen( const Coordinate p ) const;
-  QRect toScreen( const Rect r ) const;
-  QRect toScreenEnlarge( const Rect r ) const;
+  QPoint toScreen( const Coordinate& p ) const;
+  QRect toScreen( const Rect& r ) const;
+  QRect toScreenEnlarge( const Rect& r ) const;
   Coordinate fromScreen( const QPoint& p ) const;
   Rect fromScreen( const QRect& r ) const;
 
   // colors and stuff...
-  void setStyle( const PenStyle c );
+  void setStyle( Qt::PenStyle c );
   void setColor( const QColor& c );
   /**
    * setting this to -1 means to use the default width for the object
    * being drawn..  a point -> 5, other objects -> 1
    */
-  void setWidth( const int c );
-  void setPointStyle( const int p );
+  void setWidth( int c );
+  void setPointStyle( int p );
   void setPen( const QPen& p );
-  void setBrushStyle( const BrushStyle c );
+  void setBrushStyle( Qt::BrushStyle c );
   void setBrush( const QBrush& b );
   void setBrushColor( const QColor& c );
 
+  void setFont( const QFont& f );
+
+  void setSelected( bool selected );
+
   QColor getColor() const;
   bool getNightVision( ) const;
 
@@ -162,7 +165,7 @@ public:
   /**
    * draw a circle...
    */
-  void drawCircle( const Coordinate& center, const double radius );
+  void drawCircle( const Coordinate& center, double radius );
 
   /**
    * draw a segment...
@@ -198,8 +201,8 @@ public:
   /**
    * draw a polygon defined by the points in pts...
    */
-  void drawPolygon( const std::vector<QPoint>& pts, bool winding = false, int index = 0, int npoints = -1 );
-  void drawPolygon( const std::vector<Coordinate>& pts, bool winding = false, int index = 0, int npoints = -1 );
+  void drawPolygon( const std::vector<QPoint>& pts, Qt::FillRule fillRule = Qt::OddEvenFill );
+  void drawPolygon( const std::vector<Coordinate>& pts, Qt::FillRule fillRule = Qt::OddEvenFill );
 
   /**
    * draw an area defined by the points in pts filled with the set
@@ -211,16 +214,16 @@ public:
    * draw the angle with center point, with size angle, starting
    * at the angle startAngle..  Angles should be in radians.
    */
-  void drawAngle( const Coordinate& point, const double startangle,
-                  const double angle );
+  void drawAngle( const Coordinate& point, double startangle,
+                  double angle );
 
   /**
    * draw the arc ( a part of a circle ), of the circle with center
    * center, radius radius, with size angle, starting at the angle
    * startAngle..  Angles should be in radians..
    */
-  void drawArc( const Coordinate& center, const double radius,
-                const double startangle, const double angle );
+  void drawArc( const Coordinate& center, double radius,
+                double startangle, double angle );
 
   /**
    * draw a vector ( with an arrow etc. )
@@ -232,25 +235,21 @@ public:
    * draw text...
    * \see QPainter::drawText()
    */
-  void drawText( const Rect r, const QString s, int textFlags = 0,
-                 int len = -1);
-  void drawText( const Coordinate p, const QString s,
-                 int textFlags = 0, int len = -1);
+  void drawText( const Rect& r, const QString& s, int textFlags = 0 );
+  void drawText( const Coordinate& p, const QString& s, int textFlags = 0 );
 
-  void drawSimpleText( const Coordinate& c, const QString s );
+  void drawSimpleText( const Coordinate& c, const QString& s );
   void drawTextFrame( const Rect& frame, const QString& s, bool needframe );
 
-  const Rect boundingRect( const Rect& r, const QString s,
-                            int f = 0, int l = -1 ) const;
+  const Rect boundingRect( const Rect& r, const QString& s, int f = 0 ) const;
 
-  const Rect boundingRect( const Coordinate& c, const QString s,
-                            int f = 0, int l = -1 ) const;
+  const Rect boundingRect( const Coordinate& c, const QString& s, int f = 0 ) const;
 
-  const Rect simpleBoundingRect( const Coordinate& c, const QString s );
+  const Rect simpleBoundingRect( const Coordinate& c, const QString& s );
 
   void drawGrid( const CoordinateSystem& c, bool showGrid = true, bool showAxes = true );
 
-  const std::vector<QRect>& overlay() { return mOverlay; };
+  const std::vector<QRect>& overlay() { return mOverlay; }
 
 protected:
   /**
@@ -278,13 +277,15 @@ protected:
    * ...
    * \see drawText(), QPainter::boundingRect()
    */
-  void textOverlay( const QRect& r, const QString s, int textFlags, int len );
+  void textOverlay( const QRect& r, const QString& s, int textFlags );
 
   /**
    * the size we want the overlay rects to be...
    */
   double overlayRectSize();
 
+  void unsetSelected();
+
   std::vector<QRect> mOverlay;
 };
 
