@@ -21,11 +21,12 @@
 #ifndef KIG_PART_MODE_H
 #define KIG_PART_MODE_H
 
-#include <qnamespace.h>
+//#include <qnamespace.h>
 
 class KigDocument;
 class KigPart;
 class KigWidget;
+class QEventLoop;
 class QMouseEvent;
 class StdConstructionMode;
 
@@ -34,7 +35,7 @@ class StdConstructionMode;
  * document... It tells us how to respond to a certain event.
  */
 class KigMode
-  : public Qt
+//  : public Qt
 {
 public:
   virtual ~KigMode();
@@ -73,6 +74,7 @@ public:
   virtual void showHidden();
   virtual void newMacro();
   virtual void editTypes();
+  virtual void browseHistory();
   virtual void selectAll();
   virtual void deselectAll();
   virtual void invertSelection();
@@ -82,10 +84,19 @@ public:
    * refresh the screen...
    */
   virtual void redrawScreen( KigWidget* w );
+
+  /// @internal
+  void setEventLoop( QEventLoop* e );
+  /// @internal
+  QEventLoop* eventLoop() const;
+
 protected:
   KigPart& mdoc;
 
   KigMode( KigPart& d );
+
+private:
+  QEventLoop* mevloop;
 };
 
 #endif
