@@ -12,14 +12,19 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
+// mp: following a kind suggestion by David Faure the Python.h include has
+// been moved before all qt includes in order to avoid a clash related to
+// the "slots" identifier
+#include <Python.h>
 #include "python_scripter.h"
 
 #include <iostream>
 #include <string>
-#include <Python.h>
+
+//#include <Python.h>   // (see above)
 #include <boost/python.hpp>
 #include <boost/mpl/bool.hpp>
 
@@ -34,6 +39,8 @@
 #include "../objects/line_imp.h"
 #include "../objects/other_imp.h"
 #include "../objects/point_imp.h"
+#include "../objects/text_imp.h"
+#include "../objects/polygon_imp.h"
 
 using namespace boost::python;
 
@@ -227,6 +234,16 @@ BOOST_PYTHON_MODULE_INIT( kig )
     .def( "circumference", &CircleImp::circumference )
     ;
 
+  class_<PolygonImp, bases<ObjectImp>, boost::noncopyable>( "Polygon", no_init )
+    .def( "stype", &PolygonImp::stype,
+          return_value_policy<reference_existing_object>() )
+    .staticmethod( "stype" )
+    .def( "npoints", &PolygonImp::npoints )
+    .def( "perimeter", &PolygonImp::perimeter )
+    .def( "area", &PolygonImp::area )
+    .def( "windingNumber", &PolygonImp::windingNumber )
+    ;
+
   class_<VectorImp, bases<CurveImp> >( "Vector", init<Coordinate, Coordinate>() )
     .def( "stype", &VectorImp::stype,
           return_value_policy<reference_existing_object>() )
@@ -287,7 +304,7 @@ BOOST_PYTHON_MODULE_INIT( kig )
     .def( "setData", &IntImp::setData )
     ;
 
-  class_<StringImp, bases<BogusImp> >( "StringObject", no_init )
+  class_<StringImp, bases<BogusImp> >( "StringObject", init<char*>() )
     .def( "stype", &StringImp::stype,
           return_value_policy<reference_existing_object>() )
     .staticmethod( "stype" )
@@ -311,6 +328,20 @@ BOOST_PYTHON_MODULE_INIT( kig )
 //    .def( "hasFrame", &TextImp::hasFrame )
 //    ;
 
+  class_<NumericTextImp, bases<ObjectImp> >( "NumericObject", no_init )
+    .def( "stype", &NumericTextImp::stype,
+          return_value_policy<reference_existing_object>() )
+    .staticmethod( "stype" )
+    .def( "value", &NumericTextImp::getValue )
+    ;
+
+  class_<BoolTextImp, bases<ObjectImp> >( "BooleanObject", no_init )
+    .def( "stype", &BoolTextImp::stype,
+          return_value_policy<reference_existing_object>() )
+    .staticmethod( "stype" )
+    .def( "value", &BoolTextImp::getValue )
+    ;
+
   class_<CubicCartesianData>( "CubicCartesianData", init<double,double,double,double,double,double,double,double,double,double>() )
     .def( "invalidData", &CubicCartesianData::invalidData )
     .staticmethod( "invalidData" )
@@ -326,7 +357,7 @@ BOOST_PYTHON_MODULE_INIT( kig )
      .def( "data", &CubicImp::data )
      ;
 
-};
+}
 
 PythonScripter* PythonScripter::instance()
 {
@@ -346,7 +377,7 @@ static char* newstring( const char* contents )
   char* ret = new char[strlen( contents ) + 1];
   strcpy( ret, contents );
   return ret;
-};
+}
 
 PythonScripter::PythonScripter()
 {
