@@ -1,8 +1,7 @@
 /*
 * KmPlot - a math. function plotter for the KDE-Desktop
 *
-* Copyright (C) 1998, 1999  Klaus-Dieter Möller
-*               2000, 2002 kd.moeller@t-online.de
+* Copyright (C) 1998, 1999, 2000, 2002  Klaus-Dieter Möller <kd.moeller@t-online.de>
 *
 * This file is part of the KDE Project.
 * KmPlot is part of the KDE-EDU Project.
@@ -34,50 +33,49 @@
 
 // KDE includes
 #include <kaboutdata.h>
-#include <kapplication.h>
 #include <kcmdlineargs.h>
-
+#include <klocale.h>
+#include <kapplication.h>
 
 
 static const char description[] =
     I18N_NOOP( "Mathematical function plotter for KDE" );
 
-static KCmdLineOptions options[] =
-    {
-        { "+[URL]", I18N_NOOP( "File to open" ), 0 },
-        KCmdLineLastOption
-        // INSERT YOUR COMMANDLINE OPTIONS HERE
-    };
-
 
 int main( int argc, char **argv )
 {
 	KAboutData aboutData(
-	    "kmplot",
-	    I18N_NOOP( "KmPlot" ),
-	    KP_VERSION, description, KAboutData::License_GPL,
-	    "(c) 2000-2002, Klaus-Dieter Möller",
-	    0,
+	    "kmplot", 0,
+	    ki18n( "KmPlot" ),
+	    KP_VERSION, ki18n(description), KAboutData::License_GPL,
+	    ki18n("(c) 2000-2002, Klaus-Dieter Möller"),
+	    KLocalizedString(),
 	    "http://edu.kde.org/kmplot/" );
+	
 	aboutData.addAuthor(
-	    "Klaus-Dieter Möller", I18N_NOOP( "Original Author" ) ,
+	    ki18n("Klaus-Dieter Möller"), ki18n( "Original Author" ) ,
 	    "kdmoeller@foni.net" );
 	aboutData.addAuthor(
-	    "Matthias Meßmer", I18N_NOOP( "GUI" ) ,
+	    ki18n("Matthias Meßmer"), ki18n( "GUI" ) ,
 	    "bmlmessmer@web.de" );
-	aboutData.addAuthor( "Fredrik Edemar", I18N_NOOP( "Various improvements" ), "f_edemar@linux.se" );
-	aboutData.addCredit( "David Vignoni", I18N_NOOP( "svg icon" ), "david80v@tin.it" );
-	aboutData.addCredit( "Albert Astals Cid", I18N_NOOP( "command line options, MIME type" ), "tsdgeos@terra.es" );
+	aboutData.addAuthor( ki18n("Fredrik Edemar"), ki18n( "Various improvements" ), "f_edemar@linux.se" );
+	aboutData.addAuthor( ki18n("David Saxton"), ki18n( "Porting to Qt 4, UI improvements, features" ), "david@bluehaze.org" );
+	
+	aboutData.addCredit( ki18n("David Vignoni"), ki18n( "svg icon" ), "david80v@tin.it" );
+	aboutData.addCredit( ki18n("Albert Astals Cid"), ki18n( "command line options, MIME type" ), "tsdgeos@terra.es" );
 
 	KCmdLineArgs::init( argc, argv, &aboutData );
+
+	KCmdLineOptions options;
+	options.add("f");
+	options.add("function <argument>", ki18n( "Initial functions to plot" ));
+	options.add("+[URL]", ki18n( "File to open" ));
 	KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
 	KApplication ka;
 	KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
-	KmPlot *w = new KmPlot( args );
-	w->show();
-	ka.setMainWidget( w );
-	
+	new KmPlot( args );
+	QObject::connect(kapp, SIGNAL(lastWindowClosed()), kapp, SLOT(quit()));
 	return ka.exec();
 }
 
