@@ -2,12 +2,10 @@
                           kpercentage.h  -  description
                              -------------------
     begin                : Fre Nov 16 14:52:33 CET 2001
-    copyright            : (C) 2001 by Matthias Messmer &
-                                       Carsten Niehaus &
-                                       Robert Gogolok
-    email                : bmlmessmer@web.de &
-                           cniehaus@gmx.de &
-                           mail@robert-gogolok.de
+    copyright            : (C) 2001 by Matthias Messmer <bmlmessmer@web.de> &
+                                     Carsten Niehaus <cniehaus@gmx.de> &
+                                     Robert Gogolok <mail@robert-gogolok.de>
+
  ***************************************************************************/
 
 /***************************************************************************
@@ -22,16 +20,13 @@
 #ifndef KPERCENTAGE_H
 #define KPERCENTAGE_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // Qt includes
-#include <qspinbox.h>
+#include <QSpinBox>
+#include <QCloseEvent>
 
 // KDE includes
-#include <kapplication.h>
-#include <kcombobox.h>
+#include <KComboBox>
+#include <KSvgRenderer>
 
 // local includes
 #include "kpercentmain.h"
@@ -41,7 +36,7 @@
 #define SEL_PERCENTVALUE 2
 #define SEL_RANDOM 3
 
-#define KPERCENTAGE_VERSION "1.2"
+#define KPERCENTAGE_VERSION "1.3"
 
 /**
  * KPercentage is the base class of the project.
@@ -52,6 +47,7 @@ class KPercentage : public KDialog
 public:
     /** construtor */
     KPercentage( const char *name=0 );
+    ~KPercentage();
 
     /** The exercise dialog */
     KPercentMain * percent_main;
@@ -71,6 +67,8 @@ public slots: // Public slots
 protected:
     /** closes the application */
     void closeEvent(QCloseEvent *);
+    void paintEvent( QPaintEvent *e );
+    void paintBackground(QPainter &p, const QRect& rect); 
 
 private:
     /** Choose the level: easy, medium, crazy */
@@ -80,6 +78,9 @@ private:
 
     /** common preparing the exercise */
     void startExercise();
+    
+    KSvgRenderer *m_renderer;
+    QPixmap       m_backgroundCache;
 };
 
 #endif
