@@ -2,12 +2,10 @@
                        splashscreen.h  -  description
                             -------------------
    begin                : Fri Nov 30 2001
-   copyright            : (C) 2001 by Matthias Messmer &
-                                      Carsten Niehaus &
-                                      Robert Gogolok
-   email                : bmlmessmer@web.de &
-                          cniehaus@gmx.de &
-                          mail@robert-gogolok.de
+  copyright            : (C) 2001 by Matthias Messmer <bmlmessmer@web.de> &
+                                     Carsten Niehaus <cniehaus@gmx.de> &
+                                     Robert Gogolok <mail@robert-gogolok.de>
+
 ***************************************************************************/
 
 /***************************************************************************
@@ -19,42 +17,32 @@
  *                                                                         *
  ***************************************************************************/
 
-// Qt includes
-#include <qcanvas.h>
-#include <qtimer.h>
+#include "ksplashscreen.h"
+
+#include <QLabel>
+#include <QTimer>
+#include <QPixmap>
 
 // KDE includes
-#include <kstandarddirs.h>
+#include <KStandardDirs>
 
 // local includes
 #include "kpercentage.h"
-#include "ksplashscreen.h"
 
 /* creates the splash window without titlebar and border */
-KSplashScreen::KSplashScreen( KPercentage *percentage, const char *name ) :
-        KDialog( 0L, name, FALSE, QWidget::WStyle_Customize | QWidget::WStyle_NoBorder )
+KSplashScreen::KSplashScreen( KPercentage *percentage ) :
+        KDialog( 0L, Qt::FramelessWindowHint )
 {
     percentage_window = percentage;
-    resize( 400, 300 );
+    resize( 380, 300 );
     /* load the background pixmap */
-    QPixmap bgp( locate( "data", "kpercentage/pics/splash.png" ) );
+    QPixmap bgp( KStandardDirs::locate( "data", "kpercentage/pics/splash.png" ) );
+	
     /* wait some time and start the main window */
-    QCanvas *canvas = new QCanvas( this );
-    canvas->resize( 400, 300 );
-    /* set the background pixmap */
-    canvas->setBackgroundPixmap( bgp );
-    QCanvasText *t = new QCanvasText( KPERCENTAGE_VERSION, canvas );
-    t->move( 350.0, 260.0 );
-    t->show();
-    canvas->setAllChanged();
-    canvas->update();
-    QCanvasView *view = new QCanvasView( canvas, this, "", QCanvasView::WStyle_Customize | QCanvasView::WStyle_NoBorder );
-    view->resize( 400, 300 );
-    view->setVScrollBarMode( QCanvasView::AlwaysOff );
-    view->setHScrollBarMode( QCanvasView::AlwaysOff );
-    view->setFrameStyle( QCanvasView::NoFrame );
-    view->show();
-    QTimer::singleShot( 1000, this, SLOT( showPercentage() ) );
+	QLabel * label = new QLabel( this );
+	label->setFixedSize( 380, 300 );
+	label->setPixmap( bgp );
+    QTimer::singleShot( 2000, this, SLOT( showPercentage() ) );
 }
 
 /* show the main window and close the splah window */
