@@ -1,62 +1,60 @@
 #ifndef KDEEDUGLOSSARY_H
 #define KDEEDUGLOSSARY_H
 /***************************************************************************
-
-    copyright            : (C) 2005 by Carsten Niehaus
-    email                : cniehaus@kde.org
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2005, 2006 by Carsten Niehaus <cniehaus@kde.org>        *
+ *   Copyright (C) 2005 - 2007 by Pino Toscano <pino@kde.org>              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
- *                                                                         *
  ***************************************************************************/
 
+#include "libkdeedu_ui_export.h"
 
-#include <khtml_part.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 
-class QChar;
 class QDomDocument;
-class QListViewItem;
-class KListView;
-class KListViewSearchLine;
-class KActionCollection;
 class GlossaryItem;
 
 /**
  * @class Glossary
  * @author Carsten Niehaus
+ * @author Pino Toscano
  *
  * This class stores all items to be displayed. It also
  * has access-methods to the items
  */
-class Glossary
+class KDEEDUUI_EXPORT Glossary
 {
 	public:
+		/**
+		 * Creates a new glossary and add contents from an XML file.
+		 * Use isEmpty() to know if any items were loaded.
+		 *
+		 * @param url the path of the file to load
+		 * @param path the path of the pictures
+		 */
+		explicit Glossary( const KUrl& url, const QString& path = 0 );
+
+		/**
+		 * Creates a new empty glossary
+		 */
 		Glossary();
+
 		virtual ~Glossary();
 
 		/**
 		 * add the item @p item to the glossary
 		 */
-		void addItem( GlossaryItem* item ){
-			m_itemlist.append( item );
-		}
+		void addItem( GlossaryItem* item );
 
-		QValueList<GlossaryItem*> itemlist()const{
-			return m_itemlist;
-		}
+		QList<GlossaryItem*> itemlist()const;
 
 		/**
 		 * clear the Glossary
 		 */
-		void clear(){
-			m_itemlist.clear();
-		}
+		void clear();
 
 		/**
 		 * does this glossary have items?
@@ -67,77 +65,55 @@ class Glossary
 		 * Every glossary can have a name. It will be
 		 * set to @p name
 		 */
-		void setName( const QString& name ){
-			m_name = name;
-		}
+		void setName( const QString& name );
 
 		/**
 		 * @returns the name of the glossary
 		 */
-		QString name()const{
-			return m_name;
-		}
+		QString name()const;
 
 		/**
 		 * sets the internal list of items to @p list
 		 */
-		void setItemlist( QValueList<GlossaryItem*> list ){
-			m_itemlist = list;
-		}
-
-		/**
-		 * Read a glossary from an XML file.
-		 *
-		 * @param url The path of the file to load
-		 * @param path The path of the pictures. Will be used as m_picturepath
-		 *
-		 * @return a pointer to the loaded glossary. Even in case of
-		 *         error, this won't return 0 but an empty Glossary.
-		 */
-		static Glossary* readFromXML( const KURL& url, const QString& path = 0 );
+		void setItemlist( QList<GlossaryItem*> list );
 
 		/**
 		 * Every glossaryitem can show pictures. [img src="foo.png]
-		 * will look for the file foo.png in the path defined be
+		 * will look for the file foo.png in the path defined by
 		 * @p path
 		 */
-		void setPicturePath( const QString& path ){
-			m_picturepath = path;
-		}
+		void setPicturePath( const QString& path );
 
-		QString picturePath()const{
-			return m_picturepath;
-		}
+		QString picturePath()const;
 
 		/**
 		 * defines which picture to use as the background
 		 * of the htmlview. The dialog
 		 * will use the file specifiec by the @p filename
 		 */
-		void setBackgroundPicture( const QString& filename ){
-			m_backgroundpicture = filename;
-		}
+		void setBackgroundPicture( const QString& filename );
 
 		/**
 		 * @return the picuture used as the background in 
 		 * this background
 		 */
-		QString backgroundPicture()const{
-			return m_backgroundpicture;
-		}
+		QString backgroundPicture()const;
+
+	protected:
+		void init( const KUrl& url, const QString& path );
 	
 	private:
 		/**
-		 * This methods parses the given xml-code. It will extract
+		 * This methods parses the given XML code. It will extract
 		 * the information of the items and return them as a
-		 * QValueList<GlossaryItem*>
+		 * QList<GlossaryItem*>
 		 */
-		virtual QValueList<GlossaryItem*> readItems( QDomDocument &itemDocument );
+		virtual QList<GlossaryItem*> readItems( QDomDocument &itemDocument );
 		
 		QString m_backgroundpicture;
 
 		/**
-		 * replaces the [img]-pseudocode with valid html. The path where
+		 * replaces the [img]-pseudocode with valid HTML. The path where
 		 * the pictures are stored will be used for pictures
 		 */
 		void fixImagePath();
@@ -155,11 +131,11 @@ class Glossary
 		 * @param url The path of the file to load
 		 *
 		 * @return a bool indicating whether the loading of the XML was
-		 *         successfull or not
+		 *         successful or not
 		 */
-		bool loadLayout( QDomDocument& doc, const KURL& url );
+		bool loadLayout( QDomDocument& doc, const KUrl& url );
 	
-		QValueList<GlossaryItem*> m_itemlist;
+		QList<GlossaryItem*> m_itemlist;
 		
 		/**
 		 * the name of the glossary
@@ -176,47 +152,37 @@ class Glossary
  * a number of pictures or references associated to it.
  * These are stored as QStringLists.
  */
-class GlossaryItem
+class KDEEDUUI_EXPORT GlossaryItem
 {
 	public:
 		GlossaryItem(){}
 		~GlossaryItem(){}
 
-		void setName( const QString& s ){
-			m_name = s;
-		}
+		void setName( const QString& s );
 
-		void setDesc( const QString& s){
-			m_desc = s;
-		}
+		void setDesc( const QString& s);
 
-		void setRef( const QStringList& s){
-			m_ref = s;
-		}
+		/**
+		 * Set the references for the current GlossaryItem to
+		 * @p s.
+		 * There's no need to sort the list before, as they
+		 * will be sorted automatically
+		 */
+		void setRef( const QStringList& s);
 	
-		void setPictures( const QString& s ){
-			m_pic = s;
-		}
+		void setPictures( const QString& s );
 
-		QString name() const {
-			return m_name;
-		}
+		QString name() const;
 		
-		QString desc() const {
-			return m_desc;
-		}
+		QString desc() const;
 		
-		QStringList ref() const {
-			return m_ref;
-		}
+		QStringList ref() const;
 		
-		QStringList pictures() const {
-			return m_pic;
-		}
+		QStringList pictures() const;
 		
 		/**
 		 * @return the formated HTML code for current item.
-		 **/
+		 */
 		QString toHtml() const;
 
 		/**
@@ -237,55 +203,38 @@ class GlossaryItem
  * @author Pino Toscano
  * @author Carsten Niehaus
  */
-class GlossaryDialog : public KDialogBase
+class KDEEDUUI_EXPORT GlossaryDialog : public KDialog
 {
 	Q_OBJECT
 
 	public:
-		GlossaryDialog( bool folded = true, QWidget *parent=0, const char *name=0);
-		~GlossaryDialog();
+		/**
+		 * Creates a new dialog for a glossary.
+		 *
+		 * @param parent the parent of the new dialog
+		 */
+		explicit GlossaryDialog( QWidget *parent = 0 );
 
-		void keyPressEvent(QKeyEvent*);
+		virtual ~GlossaryDialog();
 
 		/**
-		 * add a new glossary
+		 * Add a new glossary.
 		 *
 		 * @param newgloss the new glossary to add
+		 * @param folded whether to fold the various items in subtrees depending on the
+		 * first letter of every item
 		 */
-		void addGlossary( Glossary* newgloss );
+		void addGlossary( Glossary* newgloss, bool folded = true );
+
+	protected:
+		void keyPressEvent(QKeyEvent*);
 
 	private:
-		QValueList<Glossary*> m_glossaries;
+		class Private;
+		Private * const d;
 
-		/**
-		 * if true the items will be displayed folded
-		 */
-		bool m_folded;
-
-		void updateTree();
-
-		KHTMLPart *m_htmlpart;
-		KListView *m_glosstree;
-		QString m_htmlbasestring;
-
-		KActionCollection* m_actionCollection;
-
-		QListViewItem* findTreeWithLetter( const QChar&, QListViewItem* );
-
-		KListViewSearchLine *m_search;
-
-	private slots:
-		void slotClicked( QListViewItem * );
-		/**
-		 * The user clicked on a href. Emit the corresponding item
-		 */
-		void displayItem( const KURL& url, const KParts::URLArgs& args );
-
-	protected slots:
-		virtual void slotClose();
-	
-	signals:
-		void closed();
+		Q_PRIVATE_SLOT( d, void itemActivated( QTreeWidgetItem *, int ) )
+		Q_PRIVATE_SLOT( d, void displayItem( const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments & ) )
 };
 
 #endif // KDEEDUGLOSSARY_H
