@@ -26,6 +26,7 @@
 //#include <QtDBus/QDBusConnection>
 
 #include "AbstractProjection.h"
+#include "MarbleDirs.h"
 #include "MarbleMap.h"
 #include "MarbleModel.h"
 #include "Quaternion.h"
@@ -34,7 +35,6 @@
 #include "FileViewModel.h"
 #include "GeoDataPoint.h"
 #include "GpxFileViewItem.h"
-#include "MarbleDirs.h"
 #include "MarblePhysics.h"
 #include "MarblePlacemarkModel.h"
 #include "MarbleWidgetInputHandler.h"
@@ -90,6 +90,8 @@ class MarbleWidgetPrivate
 
     void  construct();
 
+    void  paintEmptyMapWarning();
+
     MarbleWidget    *m_widget;
     // The model we are showing.
     MarbleMap       *m_map;
@@ -229,6 +231,31 @@ void MarbleWidgetPrivate::construct()
                         m_widget, SLOT( updateAnimation( qreal ) ) );
 }
 
+void  MarbleWidgetPrivate::paintEmptyMapWarning()
+{
+    QPainter logoPainter;
+    logoPainter.begin( m_widget );
+
+    QPixmap logoPixmap( MarbleDirs::path( "svg/marble-logo-inverted-72dpi.png" ) );
+
+    if ( logoPixmap.width() > m_widget->width() * 0.7 || logoPixmap.height() > m_widget->height() * 0.7 )
+    {
+        logoPixmap = logoPixmap.scaled( m_widget->size() * 0.7, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+    }
+
+    QPoint logoPosition( ( m_widget->width()  - logoPixmap.width() ) / 2 , 
+                            ( m_widget->height() - logoPixmap.height() ) / 2 ); 
+    logoPainter.drawPixmap( logoPosition, logoPixmap );
+
+    QString noThemeWarning = "Please assign a map theme!";
+
+    logoPainter.setPen( Qt::white );
+    QRect textRect( 0, logoPosition.y() + logoPixmap.height() + m_widget->fontMetrics().height(),
+                    m_widget->width(), m_widget->fontMetrics().height() );
+    logoPainter.drawText( textRect, Qt::AlignCenter, noThemeWarning ); 
+    logoPainter.end();
+}
+
 
 // ----------------------------------------------------------------
 
@@ -290,7 +317,7 @@ void MarbleWidget::setRadius(const int radius)
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     emit distanceChanged( distanceString() );
 
@@ -355,6 +382,11 @@ QPixmap MarbleWidget::mapScreenShot()
     return QPixmap::grabWidget( this );
 }
 
+bool MarbleWidget::showOverviewMap() const
+{
+    return d->m_map->showOverviewMap();
+}
+
 bool MarbleWidget::showScaleBar() const
 {
     return d->m_map->showScaleBar();
@@ -469,7 +501,7 @@ void MarbleWidget::zoomView(int newZoom)
 
     // We only have to repaint the background every time if the globe
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     emit distanceChanged( distanceString() );
 
@@ -499,7 +531,7 @@ void MarbleWidget::rotateBy(const Quaternion& incRot)
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
 }
@@ -510,7 +542,7 @@ void MarbleWidget::rotateBy( const double& deltaLon, const double& deltaLat)
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
 }
@@ -529,7 +561,7 @@ void MarbleWidget::centerOn( const double& lon, const double& lat, bool animated
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
 }
@@ -559,7 +591,7 @@ void MarbleWidget::centerOn( const QModelIndex& index, bool animated )
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
 }
@@ -583,7 +615,7 @@ void MarbleWidget::centerOn( const GeoDataPoint &position, bool animated )
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
 }
@@ -609,7 +641,7 @@ void MarbleWidget::setCenterLatitude( double lat )
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 }
 
 void MarbleWidget::setCenterLongitude( double lon )
@@ -618,7 +650,7 @@ void MarbleWidget::setCenterLongitude( double lon )
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 }
 
 Projection MarbleWidget::projection() const
@@ -630,7 +662,7 @@ void MarbleWidget::setProjection( Projection projection )
 {
     d->m_map->setProjection( projection );
 
-    setAttribute( Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
 }
@@ -658,55 +690,47 @@ void MarbleWidget::setHome(const GeoDataPoint& homePoint, int zoom)
 
 void MarbleWidget::moveLeft()
 {
-#if 1
-    int polarity = 0;
-
-    if ( northPoleY() != 0 )
-        polarity = northPoleY() / abs(northPoleY());
-
-    if ( polarity < 0 )
-        rotateBy( +moveStep(), 0 );
-    else
-        rotateBy( -moveStep(), 0 );
-#else
     d->m_map->moveLeft();
-#endif
+
+    // We only have to repaint the background every time if the earth
+    // doesn't cover the whole image.
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
+
+    repaint();
 }
 
 void MarbleWidget::moveRight()
 {
-#if 1
-    int polarity = 0;
-
-    if ( northPoleY() != 0 )
-        polarity = northPoleY() / abs(northPoleY());
-
-    if ( polarity < 0 )
-        rotateBy( -moveStep(), 0 );
-    else
-        rotateBy( +moveStep(), 0 );
-#else
     d->m_map->moveRight();
-#endif
+
+    // We only have to repaint the background every time if the earth
+    // doesn't cover the whole image.
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
+
+    repaint();
 }
 
 
 void MarbleWidget::moveUp()
 {
-#if 1
-    rotateBy( 0, -moveStep() );
-#else
     d->m_map->moveUp();
-#endif
+
+    // We only have to repaint the background every time if the earth
+    // doesn't cover the whole image.
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
+
+    repaint();
 }
 
 void MarbleWidget::moveDown()
 {
-#if 1
-    rotateBy( 0, +moveStep() );
-#else
     d->m_map->moveDown();
-#endif
+
+    // We only have to repaint the background every time if the earth
+    // doesn't cover the whole image.
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
+
+    repaint();
 }
 
 void MarbleWidget::leaveEvent (QEvent*)
@@ -718,7 +742,7 @@ void MarbleWidget::resizeEvent (QResizeEvent*)
 {
     d->m_map->setSize( width(), height() );
 
-    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
 }
@@ -806,6 +830,15 @@ const QRegion MarbleWidget::projectedRegion()
 
 void MarbleWidget::paintEvent(QPaintEvent *evt)
 {
+    if ( mapThemeId().isEmpty() ) 
+    {
+        d->paintEmptyMapWarning();
+        return;
+    }
+
+    QTime t;
+    t.start();
+
     // FIXME: Better way to get the GeoPainter
     bool  doClip = true;
     if ( d->m_map->projection() == Spherical )
@@ -817,7 +850,16 @@ void MarbleWidget::paintEvent(QPaintEvent *evt)
 			map()->viewParams()->mapQuality(), doClip );
 
     QRect  dirtyRect = evt->rect();
-    d->m_map->paint( painter, dirtyRect );
+
+    // Draws the map like MarbleMap::paint does, but adds our customPaint in between
+    d->m_map->d->paintGround( painter, dirtyRect );
+    d->m_map->customPaint( &painter );
+    customPaint(&painter);
+    d->m_map->d->paintOverlay( painter, dirtyRect );
+
+    double fps = 1000.0 / (double)( t.elapsed() );
+    d->m_map->d->paintFps(painter, dirtyRect, fps);
+    emit d->m_map->framesPerSecond( fps );
 }
 
 void MarbleWidget::customPaint(GeoPainter *painter)
@@ -833,7 +875,7 @@ void MarbleWidget::goHome()
 
     // We only have to repaint the background every time if the earth
     // doesn't cover the whole image.
-    setAttribute( Qt::WA_NoSystemBackground,  d->m_map->mapCoversViewport() );
+    setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint(); // not obsolete in case the zoomlevel stays unaltered
 }
@@ -871,6 +913,13 @@ void MarbleWidget::setPropertyValue( const QString& name, bool value )
     repaint();
 }
 
+void MarbleWidget::setShowOverviewMap( bool visible )
+{
+    d->m_map->setShowOverviewMap( visible );
+
+    repaint();
+}
+
 void MarbleWidget::setShowScaleBar( bool visible )
 {
     d->m_map->setShowScaleBar( visible );
